pub enum UpsertUpdateMode {
InsertOnly,
UpdateOnly,
Upsert,
}Expand description
Write mode for UPDATE MODE on UPSERT (OpenAPI UpdateMode).
Variants
InsertOnly
Only insert new points, do not update existing points.
UpdateOnly
Only update existing points, do not insert new points.
Upsert
Insert new points, update existing points (the default).