pub struct PageSpec {
pub limit: Option<u64>,
pub offset: Option<u64>,
pub limit_param: Option<String>,
pub offset_param: Option<String>,
pub limit_span: Option<Span>,
pub offset_span: Option<Span>,
}Expand description
LIMIT / OFFSET result paging.
Fields
limit: Option<u64>Maximum number of results (or groups).
offset: Option<u64>Number of results (or groups) to skip.
limit_param: Option<String>Parameter name for limit (e.g. :lim), if unbound.
offset_param: Option<String>Parameter name for offset (e.g. :off), if unbound.
limit_span: Option<Span>Source span of the limit parameter placeholder, if unbound.
offset_span: Option<Span>Source span of the offset parameter placeholder, if unbound.