collect_statement_params

Function collect_statement_params 

pub fn collect_statement_params(stmt: &Stmt) -> (BTreeSet<String>, usize)
Collect all named parameter names and the maximum positional parameter index present anywhere in a statement AST.